@@ -213,8 +213,10 @@ class ConfigparserConfigFileParser(ConfigFileParser):
         from ast import literal_eval
         # parse with configparser to allow multi-line values
         config = configparser.ConfigParser(
+            delimiters=("=",":"),
             allow_no_value=False,
-            inline_comment_prefixes=("#",),
+            comment_prefixes=("#",";"),
+            inline_comment_prefixes=("#",";"),
             strict=True,
             empty_lines_in_values=False,
         )
@@ -226,7 +228,7 @@ class ConfigparserConfigFileParser(ConfigFileParser):
         result = OrderedDict()
         for section in config.sections():
             for k,v in config[section].items():
-                multiLine2SingleLine = v.replace('\n','').replace('\r','')
+                multiLine2SingleLine = v.replace('\n',' ').replace('\r',' ')
                 # handle special case for lists
                 if '[' in multiLine2SingleLine and ']' in multiLine2SingleLine:
                     # ensure not a dict with a list value
@@ -739,11 +741,20 @@ class ArgumentParser(argparse.ArgumentParser):
                 self.error("Unexpected value for %s: '%s'. Expecting 'true', "
                            "'false', 'yes', 'no', '1' or '0'" % (key, value))
         elif isinstance(value, list):
+            accepts_list = (isinstance(action, argparse._StoreAction) and 
+                 action.nargs in ('+', '*')) or (
+                 isinstance(action, argparse._StoreAction) and
+                     isinstance(action.nargs, int) and action.nargs > 1)
+
             if action is None or isinstance(action, argparse._AppendAction):
                 for list_elem in value:
-                    args.append( "%s=%s" % (command_line_key, str(list_elem)) )
-            elif (isinstance(action, argparse._StoreAction) and action.nargs in ('+', '*')) or (
-                isinstance(action.nargs, int) and action.nargs > 1):
+                    if accepts_list and isinstance(list_elem, list):
+                        args.append(command_line_key)
+                        for sub_elem in list_elem:
+                            args.append(str(sub_elem))
+                    else:
+                        args.append( "%s=%s" % (command_line_key, str(list_elem)) )
+            elif accepts_list:
                 args.append( command_line_key )
                 for list_elem in value:
                     args.append( str(list_elem) )
